@@ -2,8 +2,8 @@
 """ default integration and unit tests for new app/namespace-root/aedev-template/... projects.
 
 remove the outsourced marker in the first line of this test module if you want to add more specialized tests. you then
-want also to replace importlib.import_module (only there to prevent syntax errors in this template) with an import
-statement.
+want also to remove ``main_imp_name`` and to replace importlib.import_module (only there to prevent syntax errors in
+this template) with an import statement.
 """
 import importlib
 import os
@@ -11,7 +11,9 @@ import os
 from ae.base import TESTS_FOLDER                # type: ignore
 from ae.inspector import module_attr            # type: ignore
 
-main_module = importlib.import_module("{'main' if os.path.isfile('main' + PY_EXT) else import_name}")
+
+main_imp_name = "{'main' if os.path.isfile(os.path.join(project_path, 'main' + PY_EXT)) else import_name}"
+main_module = importlib.import_module(main_imp_name)
 
 
 def test_version():
@@ -21,7 +23,7 @@ def test_version():
     assert pkg_version
     assert isinstance(pkg_version, str)
     assert pkg_version.count(".") == 2
-    assert pkg_version == module_attr("{import_name}", '__version__')
+    assert pkg_version == module_attr(main_imp_name, '__version__')
 
 
 def test_docstring():
@@ -29,7 +31,7 @@ def test_docstring():
     pkg_docstring = main_module.__doc__
     assert pkg_docstring
     assert isinstance(pkg_docstring, str)
-    assert pkg_docstring == module_attr("{import_name}", '__doc__')
+    assert pkg_docstring == module_attr(main_imp_name, '__doc__')
 
 
 def test_tests_folder_exists():
